@@ -1,4 +1,4 @@
-#ident "$Id: faxq-helper.c,v 4.11 2002/11/23 20:00:31 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxq-helper.c,v 4.14 2003/06/28 20:43:40 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxq-helper.c
  *
@@ -71,6 +71,8 @@ char * real_user_name;		/* user name of caller */
 int    fax_out_uid;		/* user ID to chown() fax jobs to */
 int    fax_out_gid;		/* group ID ... */
 
+#define	ROOT_UID	0	/* root's user ID - override checks */
+
 #define FAX_SEQ_FILE	".Sequence"
 #define FAX_SEQ_LOCK	"LCK..seq"
 
@@ -370,7 +372,7 @@ int fd, r, w;
 
     while( *p != '\0' )
     {
-	if ( *p != '.' && *p != ':' && ! isalnum(*p) )
+	if ( *p == '/' || *p == '\\' || isspace(*p) || !isprint(*p) )
 	{
 	    eout( "invalid char. '%c' in file name '%s', abort\n",
 		  *p, outfilename );
@@ -386,7 +388,7 @@ int fd, r, w;
 
     sprintf( pathbuf, "%s/%s", dir1, outfilename );
 
-    fd = open( pathbuf, O_WRONLY | O_CREAT | O_EXCL, 0600 );
+    fd = open( pathbuf, O_WRONLY | O_CREAT | O_EXCL, 0644 );
     if ( fd < 0 )
     {
 	eout( "can't open '%s' for writing: %s\n", pathbuf, strerror(errno));
@@ -543,6 +545,9 @@ int fd;
 
     sprintf( buf, "%s/JOB", dir1 );
 
+    /* the JOB file has to be world-readable, relax umask */
+    umask( 0022 );
+
 /* TODO: check if this portably catches symlinks to non-existant files! */
     if ( ( fd = open( buf, O_WRONLY | O_CREAT | O_EXCL, 0644 ) ) < 0 )
     {
@@ -571,7 +576,8 @@ int fd;
 
 	if ( strncmp(buf, "user ", 5) == 0 )
 	{
-	    if ( strcmp( buf+5, real_user_name ) != 0 )
+	    if ( real_user_id != ROOT_UID &&
+		 strcmp( buf+5, real_user_name ) != 0 )
 	    {
 		eout( "user name mismatch (%s <-> %s)\n", buf+5, real_user_name );
 		break;
@@ -678,7 +684,8 @@ char jfile[MAXJIDLEN+30], lfile[MAXJIDLEN+30];
 
 	if ( strncmp(buf, "user ", 5) == 0 )
 	{
-	    if ( strcmp( buf+5, real_user_name ) != 0 )
+	    if ( real_user_id != ROOT_UID &&
+		 strcmp( buf+5, real_user_name ) != 0 )
 	    {
 		fprintf( stderr, "%s: not your job, can't do anything (%s <-> %s)\n", jfile, buf+5, real_user_name );
 		unlink( lfile );
@@ -803,8 +810,11 @@ int main( int argc, char ** argv )
 
     /* common things to check and prepare */
 
-    /* directories and JOB files have to be readable */
-    umask(0022);
+    /* make sure people do not play umask tricks on us - the only
+     * bits that are accepted in a user umask are "044" - permit/prevent 
+     * read access by group/other.  Write access is always denied.
+     */
+    umask( ( umask(0) & 0044 ) | 0022 );
 
     /* get numeric uid/gid for fax user */
     pw = getpwnam( FAX_OUT_USER );
