@@ -21,13 +21,17 @@ fi
 DIFF=`ls -rt mgetty*-$VS.diff.gz 2>/dev/null |tail -1`
 test -n "$DIFF" && DIFF="put $DIFF"
 
+scp $SRC $HOST:$DST
+scp $SRC.asc $HOST:$DST.asc
+
 # normal FTP upload
-ftp -v $HOST <<EOF
-cd $DIR
-bin
-hash
-umask 022
-put $SRC $DST
-$DIFF
-quit
-EOF
+#ftp -v $HOST <<EOF
+#cd $DIR
+#bin
+#hash
+#umask 022
+#put $SRC $DST
+#put $SRC.asc $DST.asc
+#$DIFF
+#quit
+#EOF
