@@ -3,7 +3,7 @@
  *
  * autodetect the modemtype we are connected to.
  *
- * $Id: detect.c,v 1.35 2001/10/21 15:41:01 gert Exp $
+ * $Id: detect.c,v 1.42 2004/07/17 15:53:16 gert Exp $
  *
  */
 
@@ -84,6 +84,14 @@ static const struct modem_type_struct modem_database[] =
      {ati, "28642",                NULL,   &ZyXEL_2864},
      {ati, "28643",                NULL,   &ZyXEL_2864},
      {ati, "Venus V.90 USB U052099a", NULL, &Lucent},
+     {ati, "AEIGPM560LKTF1  Voice V2 V92cap", NULL, &V253modem},
+     /* Hans Fugal <hans@fugal.net>, debian bug#254404 */
+     {ati, "AEIGPM560LKTF1",       NULL,   &Lucent},
+     {ati, "Zoom V.90 PCI I030100gV -H Z207",NULL, &Lucent},
+     /* next two come from Andreas Barth, debian patches */
+     {ati, "Zoom V.90 PCI I052099gV -G Z207",NULL, &Lucent},
+     {ati, "Zoom V.90 Serial s052099g -I Z207", NULL, &Lucent},
+
      {ati, "28800",                ati6, NULL},
      {ati, "2886",                 NULL,   &US_Robotics},
      {ati, "336",                  NULL,   &Rockwell},
@@ -104,12 +112,19 @@ static const struct modem_type_struct modem_database[] =
      {ati, "3X WYSIWYF 628DBX",    NULL,   &Rockwell},
      {ati, "56000",                NULL,   &Rockwell},
      {ati, "5601",                 NULL,   &US_Robotics},
+     /* Andreas Barth, debian patch */
+     {ati, "57600",                NULL,   &Multitech_2834ZDXv},
      {ati, "961",                  NULL,   &Rockwell},
      {ati, "Digi RAS modem 56000", NULL,   &Digi_RAS},
      {ati, "Linux ISDN",           NULL,   &ISDN4Linux},
      {ati, "MT5600ZDXV",           NULL,   &Multitech_5600ZDXv},
+     {ati, "LT 33.6 MT3334ZDXV Serial Data/Fax/Voice Modem Version 1.18j",
+				   NULL, &Multitech_5634ZPX},
      {ati, "LT V.90 1.0 MT5634ZBAV Serial Data/Fax/Voice Modem Version 4.09a",
                                    NULL,   &Multitech_5634ZBAV},
+     /* Andreas Barth, debian patch */
+     {ati, "LT V.92 1.0 MT5634ZBAV-V92 Serial Data/Fax/Voice Modem Version 1.25p",
+				   NULL,   &Multitech_5634ZBAV},
      {ati4, "33600bps Voice Modem For Italy",
                                    NULL, &Rockwell},
      {ati6, "RCV336DPFSP Rev 44BC",
@@ -128,6 +143,8 @@ static const struct modem_type_struct modem_database[] =
 #endif
 
      {ati4, "WS-3314JS3", NULL, &Rockwell},
+     {ati, "LT V.90 1.0 MT5634ZPX Internal Data/Fax/Voice Modem Version 4.16h",
+                                   NULL,   &Multitech_5634ZPX_ISA},
      {ati, "LT V.90 1.0 MT5634ZPX-PCI Internal Data/Fax/Voice Modem Version 4.18f",
                                    NULL, &Multitech_5634ZPX},                                                        
      {NULL, NULL, NULL, NULL}
@@ -163,6 +180,8 @@ int voice_detect_modemtype(void)
            * First of all, let's see if a modem is connected and answering
            * and also initialize the modem echo command correctly.
            */
+	  if (cvd.command_delay.d.i != 0)
+		 delay(cvd.command_delay.d.i);
 
           if (cvd.enable_command_echo.d.i)
                {
