@@ -4,7 +4,7 @@
  * pvfecho adds echo to the sound signal. Input and output is in the pvf
  * (portable voice format) format.
  *
- * $Id: pvfecho.c,v 1.4 1998/09/09 21:07:46 gert Exp $
+ * $Id: pvfecho.c,v 1.5 1999/03/16 09:59:23 marcs Exp $
  *
  */
 
@@ -131,9 +131,11 @@ int main (int argc, char *argv[])
      delay = (int) (header_in.speed * fdelay);
      vol = (int) (ONE * fvol);
 
-     while (!feof(fd_in))
+     while (1)
           {
           data = header_in.read_pvf_data(fd_in);
+          if (feof(fd_in))
+               break;
 
           if (voice_samples >= buffer_size)
                {
