@@ -4,7 +4,7 @@
  * rmdtopvf converts from the rmd (raw modem data) format to the pvf
  * (portable voice format) format.
  *
- * $Id: rmdtopvf.c,v 1.16 2001/05/14 09:52:30 marcs Exp $
+ * $Id: rmdtopvf.c,v 1.18 2002/11/19 15:39:34 gert Exp $
  *
  */
 
@@ -47,6 +47,7 @@ static void supported_formats (void)
      fprintf(stderr, " - V.253          2 and 4 bit Rockwell ADPCM,\n");
      fprintf(stderr, "                  4 bit IMA ADPCM\n");
      fprintf(stderr, "                  8 bit linear signed/unsigned PCM\n");
+     fprintf(stderr, "                  16 bit linear signed PCM Intel Order\n");
      fprintf(stderr, "                  G.711u/A PCM\n");
      fprintf(stderr, " - ZyXEL 1496     2, 3 and 4 bit ZyXEL ADPCM\n");
      fprintf(stderr, " - ZyXEL 2864     2, 3 and 4 bit ZyXEL ADPCM\n");
@@ -264,8 +265,7 @@ int main (int argc, char *argv[])
 
           };
 
-     if (((strcmp(modem_type, "Multitech2834") == 0) ||
-      (strcmp(modem_type, "Multitech5634") == 0)) && (compression == 4))
+     if (((strcmp(modem_type, "Multitech2834") == 0) || (strcmp(modem_type, "Multitech5634") == 0)) && ((compression == 4) || compression == 132))
           {
 
           if (imaadpcmtopvf(fd_in, fd_out, &header_out) == OK)
@@ -321,6 +321,11 @@ int main (int argc, char *argv[])
             if (lintopvf(fd_in, fd_out, &header_out, 1, 0, 0) == OK)   /* signed linear */
                exit(OK);
             else exit(FAIL);
+          case 12:
+            /* signed linear PCM 16-bit Inter bit order */
+            if (lintopvf(fd_in, fd_out, &header_out, 1, 16, 1) == OK)
+               exit(OK);
+            else exit(FAIL);
           case 2:
           case 4:
             if (rockwelltopvf(fd_in, fd_out, compression, &header_out) == OK)   /* the &Elsa compatible formats */
